Learn R Programming

updateme (version 0.1.0)

updateme-package: updateme: Informative Messages About Outdated Packages

Description

When a package is loaded, the source repository is checked for new versions and a message is shown in the console indicating whether the package is out of date.

Arguments

Author

Maintainer: Jacob Scott jscott2718@gmail.com

See Also