powered by
These functions may be useful if you find the slight delay caused by updateme looking up new package versions to be slowing down your workflow.
updateme_on()updateme_off()
updateme_off()
The old updateme.on option, as returned by options()
updateme.on
options()
updateme_sources_set() to turn updateme off for individual packages
updateme_sources_set()